@@ -4,7 +4,7 @@ use 5.008009;
 use strict;
 use warnings;
 use parent qw/Exporter/;
-our $VERSION = '1.000001';
+our $VERSION = '1.000002';
 our @EXPORT_OK = qw/off/;
 
 use constant OFF_URL => 'http://offliberty.com/off02.php';
@@ -12,12 +12,12 @@ use constant OFF_URL => 'http://offliberty.com/off02.php';
 use HTML::TreeBuilder;
 use HTTP::Tiny;
 
-our $http = HTTP::Tiny->new(agent => "WWW-Offliberty/$VERSION ", default_headers => {Referer => "http://offliberty.com/"});
+our $http = HTTP::Tiny->new(agent => "WWW-Offliberty/$VERSION ", default_headers => {Referer => 'http://offliberty.com/'});
 
 sub off{
 	my ($url, @params) = @_;
 	my $ret = $http->post_form(OFF_URL, {track => $url, @params});
-	die $ret->{reason} unless $ret->{success};
+	die $ret->{reason} unless $ret->{success}; ## no critic (RequireCarping)
 	my $root = HTML::TreeBuilder->new_from_content($ret->{content});
 	map { $_->attr('href') } $root->look_down(qw/_tag a class download/);
 }
